Enum ConditionExpression
pub enum ConditionExpression {
Condition(Condition),
SimpleExpr(SimpleExpr),
}Expand description
Represents anything that can be passed to an Condition::any or Condition::all’s Condition::add method.
The arguments are automatically converted to the right enum.
Variants
Condition(Condition)
SimpleExpr(SimpleExpr)