Struct SqlxSqliteError
pub struct SqlxSqliteError {
code: i32,
message: String,
}Fields
code: i32message: StringTrait Implementations
impl DatabaseError for SqliteError
impl DatabaseError for SqliteError
fn constraint(&self) -> Option<&str>
fn constraint(&self) -> Option<&str>
Returns the name of the constraint that triggered the error, if applicable.
If the error was caused by a conflict of a unique index, this will be the index name. Read more
fn table(&self) -> Option<&str>
fn table(&self) -> Option<&str>
Returns the name of the table that was affected by the error, if applicable. Read more
fn is_unique_violation(&self) -> bool
fn is_unique_violation(&self) -> bool
Returns whether the error kind is a violation of a unique/primary key constraint.
fn is_foreign_key_violation(&self) -> bool
fn is_foreign_key_violation(&self) -> bool
Returns whether the error kind is a violation of a foreign key.
fn is_check_violation(&self) -> bool
fn is_check_violation(&self) -> bool
Returns whether the error kind is a violation of a check.
impl Debug for SqliteError
impl Debug for SqliteError
impl Display for SqliteError
impl Display for SqliteError
impl Error for SqliteError
impl Error for SqliteError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()