Enum SearchOrder
pub enum SearchOrder {
BREADTH,
DEPTH,
}Expand description
For recursive WithQuery WithClauses the traversing order can be specified in some databases that support this functionality.
Variants
BREADTH
Breadth first traversal during the execution of the recursive query.
DEPTH
Depth first traversal during the execution of the recursive query.