Search

Struct Search 

pub struct Search {
    pub(crate) order: Option<SearchOrder>,
    pub(crate) expr: Option<SelectExpr>,
}
For recursive WithQuery WithClauses the traversing order can be specified in some databases that support this functionality.

The clause contains the type of traversal: SearchOrder and the expression that is used to construct the current path.

A query can have both SEARCH and CYCLE clauses.

Setting Self::order and Self::expr is mandatory. The SelectExpr used must specify an alias which will be the name that you can use to order the result of the CommonTableExpression.

Fields

order: Option<SearchOrder>expr: Option<SelectExpr>

Implementations

pub fn new_from_order_and_expr<EXPR>(order: SearchOrder, expr: EXPR) -> Search
where EXPR: Into<SelectExpr>,

Create a complete Search specification from the SearchOrder and a SelectExpr. The given SelectExpr must have an alias specified.

pub fn new() -> Search

Constructs a new empty Search.

pub fn order(&mut self, order: SearchOrder) -> &mut Search

The traversal order to be used.

pub fn expr<EXPR>(&mut self, expr: EXPR) -> &mut Search
where EXPR: Into<SelectExpr>,

The given SelectExpr must have an alias specified.

The actual expression will be the one used to track the path in the graph.

The alias of the given SelectExpr will be the name of the order column generated by this clause.