Enum TableStatement
pub enum TableStatement {
Create(TableCreateStatement),
Alter(TableAlterStatement),
Drop(TableDropStatement),
Rename(TableRenameStatement),
Truncate(TableTruncateStatement),
}Expand description
All available types of table statement
Variants
Create(TableCreateStatement)
Alter(TableAlterStatement)
Drop(TableDropStatement)
Rename(TableRenameStatement)
Truncate(TableTruncateStatement)
Implementations
impl TableStatement
impl TableStatement
pub fn build<T>(&self, table_builder: T) -> Stringwhere
T: SchemaBuilder,
pub fn build<T>(&self, table_builder: T) -> Stringwhere
T: SchemaBuilder,
Build corresponding SQL statement for certain database backend and return SQL string
pub fn build_any(&self, table_builder: &dyn SchemaBuilder) -> String
pub fn build_any(&self, table_builder: &dyn SchemaBuilder) -> String
Build corresponding SQL statement for certain database backend and return SQL string
pub fn to_string<T>(&self, table_builder: T) -> Stringwhere
T: SchemaBuilder,
pub fn to_string<T>(&self, table_builder: T) -> Stringwhere
T: SchemaBuilder,
Build corresponding SQL statement for certain database backend and return SQL string