Struct AnyRow
pub struct AnyRow { /* private fields */ }Trait Implementations
impl<'i> ColumnIndex<AnyRow> for &'i str
impl<'i> ColumnIndex<AnyRow> for &'i str
fn index(&self, row: &AnyRow) -> Result<usize, Error>
fn index(&self, row: &AnyRow) -> Result<usize, Error>
Returns a valid positional index into the row or statement,
ColumnIndexOutOfBounds, or,
ColumnNotFound.impl ColumnIndex<AnyRow> for usize
impl ColumnIndex<AnyRow> for usize
fn index(&self, row: &AnyRow) -> Result<usize, Error>
fn index(&self, row: &AnyRow) -> Result<usize, Error>
Returns a valid positional index into the row or statement,
ColumnIndexOutOfBounds, or,
ColumnNotFound.impl Row for AnyRow
impl Row for AnyRow
type Database = Any
fn try_get_raw<I>(
&self,
index: I,
) -> Result<<<AnyRow as Row>::Database as Database>::ValueRef<'_>, Error>where
I: ColumnIndex<AnyRow>,
fn try_get_raw<I>(
&self,
index: I,
) -> Result<<<AnyRow as Row>::Database as Database>::ValueRef<'_>, Error>where
I: ColumnIndex<AnyRow>,
Index into the database row and decode a single value. Read more
fn try_get<'r, T, I>(&'r self, index: I) -> Result<T, Error>
fn try_get<'r, T, I>(&'r self, index: I) -> Result<T, Error>
Index into the database row and decode a single value. Read more
fn column<I>(&self, index: I) -> &<Self::Database as Database>::Columnwhere
I: ColumnIndex<Self>,
fn column<I>(&self, index: I) -> &<Self::Database as Database>::Columnwhere
I: ColumnIndex<Self>,
Gets the column information at
index. Read morefn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>where
I: ColumnIndex<Self>,
fn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>where
I: ColumnIndex<Self>,
Gets the column information at
index or a ColumnIndexOutOfBounds error if out of bounds.fn get<'r, T, I>(&'r self, index: I) -> T
fn get<'r, T, I>(&'r self, index: I) -> T
Index into the database row and decode a single value. Read more
fn get_unchecked<'r, T, I>(&'r self, index: I) -> T
fn get_unchecked<'r, T, I>(&'r self, index: I) -> T
Index into the database row and decode a single value. Read more
fn try_get_unchecked<'r, T, I>(&'r self, index: I) -> Result<T, Error>
fn try_get_unchecked<'r, T, I>(&'r self, index: I) -> Result<T, Error>
Index into the database row and decode a single value. Read more