ErrorKind

Enum ErrorKind 

#[non_exhaustive]
pub enum ErrorKind { UniqueViolation, ForeignKeyViolation, NotNullViolation, CheckViolation, Other, }
The error kind.

This enum is to be used to identify frequent errors that can be handled by the program. Although it currently only supports constraint violations, the type may grow in the future.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UniqueViolation

Unique/primary key constraint violation.



ForeignKeyViolation

Foreign key constraint violation.



NotNullViolation

Not-null constraint violation.



CheckViolation

Check constraint violation.



Other

An unmapped error.