Struct PoolConnectionMetadata
#[non_exhaustive]pub struct PoolConnectionMetadata {
pub age: Duration,
pub idle_for: Duration,
}Expand description
Metadata for the connection being processed by a PoolOptions callback.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.age: DurationThe duration since the connection was first opened.
For after_connect, this is Duration::ZERO.
idle_for: DurationThe duration that the connection spent in the idle queue.
Only relevant for before_acquire.
For other callbacks, this is Duration::ZERO.