Enum PgSslMode
pub enum PgSslMode {
Disable,
Allow,
Prefer,
Require,
VerifyCa,
VerifyFull,
}Expand description
Options for controlling the level of protection provided for PostgreSQL SSL connections.
It is used by the ssl_mode method.
Variants
Disable
Only try a non-SSL connection.
Allow
First try a non-SSL connection; if that fails, try an SSL connection.
Prefer
First try an SSL connection; if that fails, try a non-SSL connection.
This is the default if no other mode is specified.
Require
Only try an SSL connection. If a root CA file is present, verify the connection
in the same way as if VerifyCa was specified.
VerifyCa
Only try an SSL connection, and verify that the server certificate is issued by a trusted certificate authority (CA).
VerifyFull
Only try an SSL connection; verify that the server certificate is issued by a trusted CA and that the requested server host name matches that in the certificate.