Struct AnyConnection
pub struct AnyConnection {
pub(crate) backend: Box<dyn AnyConnectionBackend>,
}Expand description
A connection to any SQLx database.
The database driver used is determined by the scheme of the connection url.
postgres://postgres@localhost/test
sqlite://a.sqliteFields
backend: Box<dyn AnyConnectionBackend>Implementations
impl AnyConnection
impl AnyConnection
pub fn backend_name(&self) -> &str
pub fn backend_name(&self) -> &str
Returns the name of the database backend in use (e.g. PostgreSQL, MySQL, SQLite, etc.)