Struct DatabaseTransaction
pub struct DatabaseTransaction {
conn: Arc<Mutex<InnerConnection>>,
backend: DatabaseBackend,
open: bool,
metric_callback: Option<Arc<dyn Fn(&Info<'_>) + Sync + Send>>,
}Expand description
Defines a database transaction, whether it is an open transaction and the type of backend to use
Fields
conn: Arc<Mutex<InnerConnection>>backend: DatabaseBackendopen: boolmetric_callback: Option<Arc<dyn Fn(&Info<'_>) + Sync + Send>>Implementations