ExecResult

Struct ExecResult 

pub struct ExecResult {
    pub(crate) result: ExecResultHolder,
}
Defines the result of executing an operation

Fields

result: ExecResultHolder

Implementations



impl ExecResult

pub fn last_insert_id(&self) -> u64

Get the last id after AUTOINCREMENT is done on the primary key

Panics

Postgres does not support retrieving last insert id this way except through RETURNING clause

pub fn rows_affected(&self) -> u64

Get the number of rows affected by the operation