Struct Inserter
pub struct Inserter<A>where
A: ActiveModelTrait,{
primary_key: Option<ValueTuple>,
query: InsertStatement,
model: PhantomData<A>,
}Expand description
Defines a structure to perform INSERT operations in an ActiveModel
Fields
primary_key: Option<ValueTuple>query: InsertStatementmodel: PhantomData<A>Implementations
impl<A> Inserter<A>where
A: ActiveModelTrait,
impl<A> Inserter<A>where
A: ActiveModelTrait,
pub fn new(
primary_key: Option<ValueTuple>,
query: InsertStatement,
) -> Inserter<A>
pub fn new( primary_key: Option<ValueTuple>, query: InsertStatement, ) -> Inserter<A>
Instantiate a new insert operation
pub fn exec<'a, C>(
self,
db: &'a C,
) -> impl Future<Output = Result<InsertResult<A>, DbErr>> + 'awhere
C: ConnectionTrait,
A: 'a,
pub fn exec<'a, C>(
self,
db: &'a C,
) -> impl Future<Output = Result<InsertResult<A>, DbErr>> + 'awhere
C: ConnectionTrait,
A: 'a,
Execute an insert operation, returning the last inserted id
pub fn exec_without_returning<'a, C>(
self,
db: &'a C,
) -> impl Future<Output = Result<u64, DbErr>> + 'awhere
C: ConnectionTrait,
A: 'a,
pub fn exec_without_returning<'a, C>(
self,
db: &'a C,
) -> impl Future<Output = Result<u64, DbErr>> + 'awhere
C: ConnectionTrait,
A: 'a,
Execute an insert operation
pub fn exec_with_returning<'a, C>(
self,
db: &'a C,
) -> impl Future<Output = Result<<<A as ActiveModelTrait>::Entity as EntityTrait>::Model, DbErr>> + 'awhere
<<A as ActiveModelTrait>::Entity as EntityTrait>::Model: IntoActiveModel<A>,
C: ConnectionTrait,
A: 'a,
pub fn exec_with_returning<'a, C>(
self,
db: &'a C,
) -> impl Future<Output = Result<<<A as ActiveModelTrait>::Entity as EntityTrait>::Model, DbErr>> + 'awhere
<<A as ActiveModelTrait>::Entity as EntityTrait>::Model: IntoActiveModel<A>,
C: ConnectionTrait,
A: 'a,
Execute an insert operation and return the inserted model (use RETURNING syntax if supported)