Struct UpdateMany
pub struct UpdateMany<E>where
E: EntityTrait,{
pub(crate) query: UpdateStatement,
pub(crate) entity: PhantomData<E>,
}Expand description
Defines an UPDATE operation on multiple ActiveModels
Fields
query: UpdateStatemententity: PhantomData<E>Implementations
impl<'a, E> UpdateMany<E>where
E: EntityTrait,
impl<'a, E> UpdateMany<E>where
E: EntityTrait,
pub async fn exec<C>(self, db: &'a C) -> Result<UpdateResult, DbErr>where
C: ConnectionTrait,
pub async fn exec<C>(self, db: &'a C) -> Result<UpdateResult, DbErr>where
C: ConnectionTrait,
Execute an update operation on multiple ActiveModels
pub async fn exec_with_returning<C>(
self,
db: &'a C,
) -> Result<Vec<<E as EntityTrait>::Model>, DbErr>where
C: ConnectionTrait,
pub async fn exec_with_returning<C>(
self,
db: &'a C,
) -> Result<Vec<<E as EntityTrait>::Model>, DbErr>where
C: ConnectionTrait,
Execute an update operation and return the updated model (use RETURNING syntax if supported)
Panics
Panics if the database backend does not support UPDATE RETURNING.
impl<E> UpdateMany<E>where
E: EntityTrait,
impl<E> UpdateMany<E>where
E: EntityTrait,
pub fn set<A>(self, model: A) -> UpdateMany<E>where
A: ActiveModelTrait<Entity = E>,
pub fn set<A>(self, model: A) -> UpdateMany<E>where
A: ActiveModelTrait<Entity = E>,
Add the models to update to Self
pub fn col_expr<T>(self, col: T, expr: SimpleExpr) -> UpdateMany<E>where
T: IntoIden,
pub fn col_expr<T>(self, col: T, expr: SimpleExpr) -> UpdateMany<E>where
T: IntoIden,
Creates a SimpleExpr from a column