Enum ParseError
pub enum ParseError {
VariantNotFound,
}Expand description
The ParseError enum is a collection of all the possible reasons
an enum can fail to parse from a string.
Variants
VariantNotFound